@@ -2,6 +2,10 @@
 #'
 #' @importFrom utils globalVariables
 "_PACKAGE"
+
+FEDSTAT_URL_BASE <- "https://www.fedstat.ru"
+
 globalVariables(c(
-  "."
+  ".",
+  FEDSTAT_URL_BASE
 ))
